CLU – Common Lightweight Utilities (née Command-Line Utilities)
==================================================

This is a packaged-up and sanely version-controlled version of [the Python tools I wrote for my REPLs](https://github.com/fish2000/homage/blob/master/.script-bin/replutilities.py), divided up into
a bunch of subordinate packages.

If you assumed that the project name was a Tron reference, you are in fact correct.